# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from freeclimb.configuration import Configuration


class RecordingResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'uri': 'str',
        'date_created': 'str',
        'date_updated': 'str',
        'revision': 'int',
        'recording_id': 'str',
        'account_id': 'str',
        'call_id': 'str',
        'duration_sec': 'int',
        'conference_id': 'str'
    }

    attribute_map = {
        'uri': 'uri',
        'date_created': 'dateCreated',
        'date_updated': 'dateUpdated',
        'revision': 'revision',
        'recording_id': 'recordingId',
        'account_id': 'accountId',
        'call_id': 'callId',
        'duration_sec': 'durationSec',
        'conference_id': 'conferenceId'
    }

    def __init__(self, uri=None, date_created=None, date_updated=None, revision=None, recording_id=None, account_id=None, call_id=None, duration_sec=None, conference_id=None, local_vars_configuration=None):  # noqa: E501
        """RecordingResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._uri = None
        self._date_created = None
        self._date_updated = None
        self._revision = None
        self._recording_id = None
        self._account_id = None
        self._call_id = None
        self._duration_sec = None
        self._conference_id = None
        self.discriminator = None

        if uri is not None:
            self.uri = uri
        if date_created is not None:
            self.date_created = date_created
        if date_updated is not None:
            self.date_updated = date_updated
        if revision is not None:
            self.revision = revision
        if recording_id is not None:
            self.recording_id = recording_id
        if account_id is not None:
            self.account_id = account_id
        if call_id is not None:
            self.call_id = call_id
        if duration_sec is not None:
            self.duration_sec = duration_sec
        if conference_id is not None:
            self.conference_id = conference_id

    @property
    def uri(self):
        """Gets the uri of this RecordingResult.  # noqa: E501

        The URI for this resource, relative to /apiserver.  # noqa: E501

        :return: The uri of this RecordingResult.  # noqa: E501
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """Sets the uri of this RecordingResult.

        The URI for this resource, relative to /apiserver.  # noqa: E501

        :param uri: The uri of this RecordingResult.  # noqa: E501
        :type: str
        """

        self._uri = uri

    @property
    def date_created(self):
        """Gets the date_created of this RecordingResult.  # noqa: E501

        The date that this resource was created (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).  # noqa: E501

        :return: The date_created of this RecordingResult.  # noqa: E501
        :rtype: str
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this RecordingResult.

        The date that this resource was created (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).  # noqa: E501

        :param date_created: The date_created of this RecordingResult.  # noqa: E501
        :type: str
        """

        self._date_created = date_created

    @property
    def date_updated(self):
        """Gets the date_updated of this RecordingResult.  # noqa: E501

        The date that this resource was last updated (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).  # noqa: E501

        :return: The date_updated of this RecordingResult.  # noqa: E501
        :rtype: str
        """
        return self._date_updated

    @date_updated.setter
    def date_updated(self, date_updated):
        """Sets the date_updated of this RecordingResult.

        The date that this resource was last updated (GMT) in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).  # noqa: E501

        :param date_updated: The date_updated of this RecordingResult.  # noqa: E501
        :type: str
        """

        self._date_updated = date_updated

    @property
    def revision(self):
        """Gets the revision of this RecordingResult.  # noqa: E501

        Revision count for the resource. This count is set to 1 on creation and is incremented every time it is updated.  # noqa: E501

        :return: The revision of this RecordingResult.  # noqa: E501
        :rtype: int
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """Sets the revision of this RecordingResult.

        Revision count for the resource. This count is set to 1 on creation and is incremented every time it is updated.  # noqa: E501

        :param revision: The revision of this RecordingResult.  # noqa: E501
        :type: int
        """

        self._revision = revision

    @property
    def recording_id(self):
        """Gets the recording_id of this RecordingResult.  # noqa: E501

        String that uniquely identifies this recording resource.  # noqa: E501

        :return: The recording_id of this RecordingResult.  # noqa: E501
        :rtype: str
        """
        return self._recording_id

    @recording_id.setter
    def recording_id(self, recording_id):
        """Sets the recording_id of this RecordingResult.

        String that uniquely identifies this recording resource.  # noqa: E501

        :param recording_id: The recording_id of this RecordingResult.  # noqa: E501
        :type: str
        """

        self._recording_id = recording_id

    @property
    def account_id(self):
        """Gets the account_id of this RecordingResult.  # noqa: E501

        ID of the account that created this recording.  # noqa: E501

        :return: The account_id of this RecordingResult.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this RecordingResult.

        ID of the account that created this recording.  # noqa: E501

        :param account_id: The account_id of this RecordingResult.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def call_id(self):
        """Gets the call_id of this RecordingResult.  # noqa: E501

        ID of the Call that was recorded. If a Conference was recorded, this value is empty and the conferenceId property is populated.  # noqa: E501

        :return: The call_id of this RecordingResult.  # noqa: E501
        :rtype: str
        """
        return self._call_id

    @call_id.setter
    def call_id(self, call_id):
        """Sets the call_id of this RecordingResult.

        ID of the Call that was recorded. If a Conference was recorded, this value is empty and the conferenceId property is populated.  # noqa: E501

        :param call_id: The call_id of this RecordingResult.  # noqa: E501
        :type: str
        """

        self._call_id = call_id

    @property
    def duration_sec(self):
        """Gets the duration_sec of this RecordingResult.  # noqa: E501

        Length of the recording in seconds.  # noqa: E501

        :return: The duration_sec of this RecordingResult.  # noqa: E501
        :rtype: int
        """
        return self._duration_sec

    @duration_sec.setter
    def duration_sec(self, duration_sec):
        """Sets the duration_sec of this RecordingResult.

        Length of the recording in seconds.  # noqa: E501

        :param duration_sec: The duration_sec of this RecordingResult.  # noqa: E501
        :type: int
        """

        self._duration_sec = duration_sec

    @property
    def conference_id(self):
        """Gets the conference_id of this RecordingResult.  # noqa: E501

        ID of the Conference that was recorded. If a Call was recorded, this value is empty and the callId property is populated.  # noqa: E501

        :return: The conference_id of this RecordingResult.  # noqa: E501
        :rtype: str
        """
        return self._conference_id

    @conference_id.setter
    def conference_id(self, conference_id):
        """Sets the conference_id of this RecordingResult.

        ID of the Conference that was recorded. If a Call was recorded, this value is empty and the callId property is populated.  # noqa: E501

        :param conference_id: The conference_id of this RecordingResult.  # noqa: E501
        :type: str
        """

        self._conference_id = conference_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.to_camel_case(attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif value is None:
                continue
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RecordingResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RecordingResult):
            return True

        return self.to_dict() != other.to_dict()

    def to_camel_case(self, snake_str):
        components = snake_str.split('_')
        return components[0] + ''.join(x.title() for x in components[1:])



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from freeclimb.configuration import Configuration


class ConferenceParticipantResultAllOf(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'str',
        'conference_id': 'str',
        'call_id': 'str',
        'talk': 'bool',
        'listen': 'bool',
        'start_conf_on_enter': 'bool'
    }

    attribute_map = {
        'account_id': 'accountId',
        'conference_id': 'conferenceId',
        'call_id': 'callId',
        'talk': 'talk',
        'listen': 'listen',
        'start_conf_on_enter': 'startConfOnEnter'
    }

    def __init__(self, account_id=None, conference_id=None, call_id=None, talk=None, listen=None, start_conf_on_enter=None, local_vars_configuration=None):  # noqa: E501
        """ConferenceParticipantResultAllOf - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._conference_id = None
        self._call_id = None
        self._talk = None
        self._listen = None
        self._start_conf_on_enter = None
        self.discriminator = None

        if account_id is not None:
            self.account_id = account_id
        if conference_id is not None:
            self.conference_id = conference_id
        if call_id is not None:
            self.call_id = call_id
        if talk is not None:
            self.talk = talk
        if listen is not None:
            self.listen = listen
        if start_conf_on_enter is not None:
            self.start_conf_on_enter = start_conf_on_enter

    @property
    def account_id(self):
        """Gets the account_id of this ConferenceParticipantResultAllOf.  # noqa: E501

        ID of the account that created this participant.  # noqa: E501

        :return: The account_id of this ConferenceParticipantResultAllOf.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this ConferenceParticipantResultAllOf.

        ID of the account that created this participant.  # noqa: E501

        :param account_id: The account_id of this ConferenceParticipantResultAllOf.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def conference_id(self):
        """Gets the conference_id of this ConferenceParticipantResultAllOf.  # noqa: E501

        ID of the conference this participant is in.  # noqa: E501

        :return: The conference_id of this ConferenceParticipantResultAllOf.  # noqa: E501
        :rtype: str
        """
        return self._conference_id

    @conference_id.setter
    def conference_id(self, conference_id):
        """Sets the conference_id of this ConferenceParticipantResultAllOf.

        ID of the conference this participant is in.  # noqa: E501

        :param conference_id: The conference_id of this ConferenceParticipantResultAllOf.  # noqa: E501
        :type: str
        """

        self._conference_id = conference_id

    @property
    def call_id(self):
        """Gets the call_id of this ConferenceParticipantResultAllOf.  # noqa: E501

        ID of the Call associated with this Participant.  # noqa: E501

        :return: The call_id of this ConferenceParticipantResultAllOf.  # noqa: E501
        :rtype: str
        """
        return self._call_id

    @call_id.setter
    def call_id(self, call_id):
        """Sets the call_id of this ConferenceParticipantResultAllOf.

        ID of the Call associated with this Participant.  # noqa: E501

        :param call_id: The call_id of this ConferenceParticipantResultAllOf.  # noqa: E501
        :type: str
        """

        self._call_id = call_id

    @property
    def talk(self):
        """Gets the talk of this ConferenceParticipantResultAllOf.  # noqa: E501

        True if this Participant has talk privileges in the Conference. False otherwise.  # noqa: E501

        :return: The talk of this ConferenceParticipantResultAllOf.  # noqa: E501
        :rtype: bool
        """
        return self._talk

    @talk.setter
    def talk(self, talk):
        """Sets the talk of this ConferenceParticipantResultAllOf.

        True if this Participant has talk privileges in the Conference. False otherwise.  # noqa: E501

        :param talk: The talk of this ConferenceParticipantResultAllOf.  # noqa: E501
        :type: bool
        """

        self._talk = talk

    @property
    def listen(self):
        """Gets the listen of this ConferenceParticipantResultAllOf.  # noqa: E501

        True if this Participant has listen privileges in the Conference. False otherwise.  # noqa: E501

        :return: The listen of this ConferenceParticipantResultAllOf.  # noqa: E501
        :rtype: bool
        """
        return self._listen

    @listen.setter
    def listen(self, listen):
        """Sets the listen of this ConferenceParticipantResultAllOf.

        True if this Participant has listen privileges in the Conference. False otherwise.  # noqa: E501

        :param listen: The listen of this ConferenceParticipantResultAllOf.  # noqa: E501
        :type: bool
        """

        self._listen = listen

    @property
    def start_conf_on_enter(self):
        """Gets the start_conf_on_enter of this ConferenceParticipantResultAllOf.  # noqa: E501

        True if this Participant joining the Conference caused the Conference to start (status = inProgress). False otherwise.  # noqa: E501

        :return: The start_conf_on_enter of this ConferenceParticipantResultAllOf.  # noqa: E501
        :rtype: bool
        """
        return self._start_conf_on_enter

    @start_conf_on_enter.setter
    def start_conf_on_enter(self, start_conf_on_enter):
        """Sets the start_conf_on_enter of this ConferenceParticipantResultAllOf.

        True if this Participant joining the Conference caused the Conference to start (status = inProgress). False otherwise.  # noqa: E501

        :param start_conf_on_enter: The start_conf_on_enter of this ConferenceParticipantResultAllOf.  # noqa: E501
        :type: bool
        """

        self._start_conf_on_enter = start_conf_on_enter

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.to_camel_case(attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif value is None:
                continue
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConferenceParticipantResultAllOf):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ConferenceParticipantResultAllOf):
            return True

        return self.to_dict() != other.to_dict()

    def to_camel_case(self, snake_str):
        components = snake_str.split('_')
        return components[0] + ''.join(x.title() for x in components[1:])



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from freeclimb.configuration import Configuration


class SmsAllOf(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'to': 'str',
        '_from': 'str',
        'text': 'str',
        'notification_url': 'str'
    }

    attribute_map = {
        'to': 'to',
        '_from': 'from',
        'text': 'text',
        'notification_url': 'notificationUrl'
    }

    def __init__(self, to=None, _from=None, text=None, notification_url=None, local_vars_configuration=None):  # noqa: E501
        """SmsAllOf - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._to = None
        self.__from = None
        self._text = None
        self._notification_url = None
        self.discriminator = None

        self.to = to
        self._from = _from
        self.text = text
        if notification_url is not None:
            self.notification_url = notification_url

    @property
    def to(self):
        """Gets the to of this SmsAllOf.  # noqa: E501

        E.164 representation of the phone number to which the message will be sent. Must be within FreeClimb's service area and E.164 formatting (e.g., +18003608245).  # noqa: E501

        :return: The to of this SmsAllOf.  # noqa: E501
        :rtype: str
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this SmsAllOf.

        E.164 representation of the phone number to which the message will be sent. Must be within FreeClimb's service area and E.164 formatting (e.g., +18003608245).  # noqa: E501

        :param to: The to of this SmsAllOf.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and to is None:  # noqa: E501
            raise ValueError("Invalid value for `to`, must not be `None`")  # noqa: E501

        self._to = to

    @property
    def _from(self):
        """Gets the _from of this SmsAllOf.  # noqa: E501

        E.164 representation of the phone number to use as the sender. This must be an incoming phone number you have purchased from FreeClimb.  # noqa: E501

        :return: The _from of this SmsAllOf.  # noqa: E501
        :rtype: str
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this SmsAllOf.

        E.164 representation of the phone number to use as the sender. This must be an incoming phone number you have purchased from FreeClimb.  # noqa: E501

        :param _from: The _from of this SmsAllOf.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and _from is None:  # noqa: E501
            raise ValueError("Invalid value for `_from`, must not be `None`")  # noqa: E501

        self.__from = _from

    @property
    def text(self):
        """Gets the text of this SmsAllOf.  # noqa: E501

        Text contained in the message (maximum 160 characters).  # noqa: E501

        :return: The text of this SmsAllOf.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this SmsAllOf.

        Text contained in the message (maximum 160 characters).  # noqa: E501

        :param text: The text of this SmsAllOf.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and text is None:  # noqa: E501
            raise ValueError("Invalid value for `text`, must not be `None`")  # noqa: E501

        self._text = text

    @property
    def notification_url(self):
        """Gets the notification_url of this SmsAllOf.  # noqa: E501

        When the message changes status, this URL will be invoked using HTTP POST with the messageStatus parameters. This is a notification only; any PerCL returned will be ignored.  # noqa: E501

        :return: The notification_url of this SmsAllOf.  # noqa: E501
        :rtype: str
        """
        return self._notification_url

    @notification_url.setter
    def notification_url(self, notification_url):
        """Sets the notification_url of this SmsAllOf.

        When the message changes status, this URL will be invoked using HTTP POST with the messageStatus parameters. This is a notification only; any PerCL returned will be ignored.  # noqa: E501

        :param notification_url: The notification_url of this SmsAllOf.  # noqa: E501
        :type: str
        """

        self._notification_url = notification_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.to_camel_case(attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif value is None:
                continue
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SmsAllOf):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SmsAllOf):
            return True

        return self.to_dict() != other.to_dict()

    def to_camel_case(self, snake_str):
        components = snake_str.split('_')
        return components[0] + ''.join(x.title() for x in components[1:])



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from freeclimb.configuration import Configuration


class LogResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'timestamp': 'int',
        'level': 'str',
        'request_id': 'str',
        'account_id': 'str',
        'call_id': 'str',
        'message': 'str',
        'metadata': 'object'
    }

    attribute_map = {
        'timestamp': 'timestamp',
        'level': 'level',
        'request_id': 'requestId',
        'account_id': 'accountId',
        'call_id': 'callId',
        'message': 'message',
        'metadata': 'metadata'
    }

    def __init__(self, timestamp=None, level=None, request_id=None, account_id=None, call_id=None, message=None, metadata=None, local_vars_configuration=None):  # noqa: E501
        """LogResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._timestamp = None
        self._level = None
        self._request_id = None
        self._account_id = None
        self._call_id = None
        self._message = None
        self._metadata = None
        self.discriminator = None

        if timestamp is not None:
            self.timestamp = timestamp
        if level is not None:
            self.level = level
        if request_id is not None:
            self.request_id = request_id
        if account_id is not None:
            self.account_id = account_id
        if call_id is not None:
            self.call_id = call_id
        if message is not None:
            self.message = message
        if metadata is not None:
            self.metadata = metadata

    @property
    def timestamp(self):
        """Gets the timestamp of this LogResult.  # noqa: E501

        Time that the log was generated. The time is represented as microseconds since the Unix Epoch.  # noqa: E501

        :return: The timestamp of this LogResult.  # noqa: E501
        :rtype: int
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this LogResult.

        Time that the log was generated. The time is represented as microseconds since the Unix Epoch.  # noqa: E501

        :param timestamp: The timestamp of this LogResult.  # noqa: E501
        :type: int
        """

        self._timestamp = timestamp

    @property
    def level(self):
        """Gets the level of this LogResult.  # noqa: E501

        Level of the log. Possible values are info, warning, and error.  # noqa: E501

        :return: The level of this LogResult.  # noqa: E501
        :rtype: str
        """
        return self._level

    @level.setter
    def level(self, level):
        """Sets the level of this LogResult.

        Level of the log. Possible values are info, warning, and error.  # noqa: E501

        :param level: The level of this LogResult.  # noqa: E501
        :type: str
        """
        allowed_values = ["info", "warning", "error"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and level not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `level` ({0}), must be one of {1}"  # noqa: E501
                .format(level, allowed_values)
            )

        self._level = level

    @property
    def request_id(self):
        """Gets the request_id of this LogResult.  # noqa: E501

        ID of the request associated with the log. The requestId is propagated across all logs generated by FreeClimb when processing a request.  # noqa: E501

        :return: The request_id of this LogResult.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this LogResult.

        ID of the request associated with the log. The requestId is propagated across all logs generated by FreeClimb when processing a request.  # noqa: E501

        :param request_id: The request_id of this LogResult.  # noqa: E501
        :type: str
        """

        self._request_id = request_id

    @property
    def account_id(self):
        """Gets the account_id of this LogResult.  # noqa: E501

        ID of the account that this log was generated under.  # noqa: E501

        :return: The account_id of this LogResult.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this LogResult.

        ID of the account that this log was generated under.  # noqa: E501

        :param account_id: The account_id of this LogResult.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def call_id(self):
        """Gets the call_id of this LogResult.  # noqa: E501

        ID of the Call associated with the log. Can be set to null if the log was generated without regard to a specific Call.  # noqa: E501

        :return: The call_id of this LogResult.  # noqa: E501
        :rtype: str
        """
        return self._call_id

    @call_id.setter
    def call_id(self, call_id):
        """Sets the call_id of this LogResult.

        ID of the Call associated with the log. Can be set to null if the log was generated without regard to a specific Call.  # noqa: E501

        :param call_id: The call_id of this LogResult.  # noqa: E501
        :type: str
        """

        self._call_id = call_id

    @property
    def message(self):
        """Gets the message of this LogResult.  # noqa: E501

        A simple string describing the event being logged.  # noqa: E501

        :return: The message of this LogResult.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this LogResult.

        A simple string describing the event being logged.  # noqa: E501

        :param message: The message of this LogResult.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def metadata(self):
        """Gets the metadata of this LogResult.  # noqa: E501

        JSON document containing metadata about the event. Some log messages may include request and response header content in this field.  # noqa: E501

        :return: The metadata of this LogResult.  # noqa: E501
        :rtype: object
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this LogResult.

        JSON document containing metadata about the event. Some log messages may include request and response header content in this field.  # noqa: E501

        :param metadata: The metadata of this LogResult.  # noqa: E501
        :type: object
        """

        self._metadata = metadata

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.to_camel_case(attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif value is None:
                continue
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LogResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LogResult):
            return True

        return self.to_dict() != other.to_dict()

    def to_camel_case(self, snake_str):
        components = snake_str.split('_')
        return components[0] + ''.join(x.title() for x in components[1:])



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from freeclimb.configuration import Configuration


class EnqueueAllOf(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'action_url': 'str',
        'notification_url': 'str',
        'queue_id': 'str',
        'wait_url': 'str'
    }

    attribute_map = {
        'action_url': 'actionUrl',
        'notification_url': 'notificationUrl',
        'queue_id': 'queueId',
        'wait_url': 'waitUrl'
    }

    def __init__(self, action_url=None, notification_url=None, queue_id=None, wait_url=None, local_vars_configuration=None):  # noqa: E501
        """EnqueueAllOf - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._action_url = None
        self._notification_url = None
        self._queue_id = None
        self._wait_url = None
        self.discriminator = None

        self.action_url = action_url
        if notification_url is not None:
            self.notification_url = notification_url
        self.queue_id = queue_id
        self.wait_url = wait_url

    @property
    def action_url(self):
        """Gets the action_url of this EnqueueAllOf.  # noqa: E501

        A request is made to this URL when the Call leaves the Queue, which can occur if enqueue of the Call fails or when the call is dequeued via the `Dequeue` command, the REST API (POST to Queue Member resource), or the caller hangs up.  # noqa: E501

        :return: The action_url of this EnqueueAllOf.  # noqa: E501
        :rtype: str
        """
        return self._action_url

    @action_url.setter
    def action_url(self, action_url):
        """Sets the action_url of this EnqueueAllOf.

        A request is made to this URL when the Call leaves the Queue, which can occur if enqueue of the Call fails or when the call is dequeued via the `Dequeue` command, the REST API (POST to Queue Member resource), or the caller hangs up.  # noqa: E501

        :param action_url: The action_url of this EnqueueAllOf.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and action_url is None:  # noqa: E501
            raise ValueError("Invalid value for `action_url`, must not be `None`")  # noqa: E501

        self._action_url = action_url

    @property
    def notification_url(self):
        """Gets the notification_url of this EnqueueAllOf.  # noqa: E501

        URL to be invoked when the call enters the queue. The request to the URL contains the standard request parameters.This is a notification only; any PerCL returned will be ignored.  # noqa: E501

        :return: The notification_url of this EnqueueAllOf.  # noqa: E501
        :rtype: str
        """
        return self._notification_url

    @notification_url.setter
    def notification_url(self, notification_url):
        """Sets the notification_url of this EnqueueAllOf.

        URL to be invoked when the call enters the queue. The request to the URL contains the standard request parameters.This is a notification only; any PerCL returned will be ignored.  # noqa: E501

        :param notification_url: The notification_url of this EnqueueAllOf.  # noqa: E501
        :type: str
        """

        self._notification_url = notification_url

    @property
    def queue_id(self):
        """Gets the queue_id of this EnqueueAllOf.  # noqa: E501

        ID of the Queue to which to add the Call. If the Queue does not exist, it will be created. The ID must start with QU followed by 40 hex characters.  # noqa: E501

        :return: The queue_id of this EnqueueAllOf.  # noqa: E501
        :rtype: str
        """
        return self._queue_id

    @queue_id.setter
    def queue_id(self, queue_id):
        """Sets the queue_id of this EnqueueAllOf.

        ID of the Queue to which to add the Call. If the Queue does not exist, it will be created. The ID must start with QU followed by 40 hex characters.  # noqa: E501

        :param queue_id: The queue_id of this EnqueueAllOf.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and queue_id is None:  # noqa: E501
            raise ValueError("Invalid value for `queue_id`, must not be `None`")  # noqa: E501

        self._queue_id = queue_id

    @property
    def wait_url(self):
        """Gets the wait_url of this EnqueueAllOf.  # noqa: E501

        A request is made to this URL when the Call leaves the Queue, which can occur if enqueue of the Call fails or when the call is dequeued via the `Dequeue` command, the REST API (POST to Queue Member resource), or the caller hangs up.  # noqa: E501

        :return: The wait_url of this EnqueueAllOf.  # noqa: E501
        :rtype: str
        """
        return self._wait_url

    @wait_url.setter
    def wait_url(self, wait_url):
        """Sets the wait_url of this EnqueueAllOf.

        A request is made to this URL when the Call leaves the Queue, which can occur if enqueue of the Call fails or when the call is dequeued via the `Dequeue` command, the REST API (POST to Queue Member resource), or the caller hangs up.  # noqa: E501

        :param wait_url: The wait_url of this EnqueueAllOf.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and wait_url is None:  # noqa: E501
            raise ValueError("Invalid value for `wait_url`, must not be `None`")  # noqa: E501

        self._wait_url = wait_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.to_camel_case(attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif value is None:
                continue
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EnqueueAllOf):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EnqueueAllOf):
            return True

        return self.to_dict() != other.to_dict()

    def to_camel_case(self, snake_str):
        components = snake_str.split('_')
        return components[0] + ''.join(x.title() for x in components[1:])



# coding: utf-8

"""
    FreeClimb API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import mock

import freeclimb
from freeclimb.api.default_api import DefaultApi  # noqa: E501
from freeclimb.rest import ApiException
import pprint


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = freeclimb.api.default_api.DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_buy_a_phone_number(self):
        """Test case for buy_a_phone_number

        Buy a Phone Number  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:

            buy_incoming_number_request = freeclimb.BuyIncomingNumberRequest('+12345678900')
            self.test_buy_a_phone_number_response = self.api.buy_a_phone_number(buy_incoming_number_request=buy_incoming_number_request)

            mock_method.assert_called_once()
            # TODO: Fails because actual result has newlines in dictionary and the following removes the newlines
            # mock_method.assert_called_once_with(
            #     '/Accounts/{accountId}/IncomingPhoneNumbers',
            #     'POST',
            #     {'accountId': 'ACCOUNT_ID'},
            #     [],
            #     {'Accept': 'application/json', 'Content-Type': 'application/json'},
            #     _preload_content=True,
            #     _request_timeout=None,
            #     _return_http_data_only=True, async_req=None, auth_settings=['fc'], body={
            #         'alias': None,
            #         'application_id': None,
            #         'phone_number': '+12345678900',
            #         'request_id': None
            #     },
            #     collection_formats={},
            #     files={},
            #     post_params=[],
            #     response_type='IncomingNumberResult'
            # )

    def test_create_a_conference(self):
        """Test case for create_a_conference

        Create a Conference  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            create_conference_request = freeclimb.CreateConferenceRequest('http://localhost:80')
            self.test_create_a_conference_response = self.api.create_a_conference(create_conference_request=create_conference_request)

            mock_method.assert_called_once()

    def test_create_a_queue(self):
        """Test case for create_a_queue

        Create a Queue  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_create_a_queue_response = self.api.create_a_queue(queue_request=freeclimb.QueueRequest())

            mock_method.assert_called_once()

    def test_create_an_application(self):
        """Test case for create_an_application

        Create an application  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_create_an_application = self.api.create_an_application(application_request=freeclimb.ApplicationRequest())

            mock_method.assert_called_once()

    def test_delete_a_recording(self):
        """Test case for delete_a_recording

        Delete a Recording  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_delete_a_recording = self.api.delete_a_recording(recording_id='fake_recording_id')

            mock_method.assert_called_once()

    def test_delete_an_application(self):
        """Test case for delete_an_application

        Delete an application  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_delete_an_application = self.api.delete_an_application(application_id='fake_application_id')

            mock_method.assert_called_once()

    def test_delete_an_incoming_number(self):
        """Test case for delete_an_incoming_number

        Delete an Incoming Number  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_delete_an_incoming_number = self.api.delete_an_incoming_number(phone_number_id='fake_incoming_number_id')

            mock_method.assert_called_once()

    def test_dequeue_a_member(self):
        """Test case for dequeue_a_member

        Dequeue a Member  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_dequeue_a_member = self.api.dequeue_a_member(queue_id='fake_queue_id', call_id='fake_call_id')

            mock_method.assert_called_once()

    def test_dequeue_head_member(self):
        """Test case for dequeue_head_member

        Dequeue Head Member  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_dequeue_head_member = self.api.dequeue_head_member(queue_id='fake_queue_id')

            mock_method.assert_called_once()

    def test_download_a_recording_file(self):
        """Test case for download_a_recording_file

        Download a Recording File  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_download_a_recording_file = self.api.download_a_recording_file(recording_id='fake_recording_id')

            mock_method.assert_called_once()

    def test_filter_logs(self):
        """Test case for filter_logs

        Filter Logs  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_filter_logs = self.api.filter_logs(filter_logs_request=freeclimb.FilterLogsRequest(pql='fake_pql'))

            mock_method.assert_called_once()

    def test_get_a_call(self):
        """Test case for get_a_call

        Get a Call  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_get_a_call = self.api.get_a_call(call_id='fake_call_id')

            mock_method.assert_called_once()

    def test_get_a_conference(self):
        """Test case for get_a_conference

        Get a Conference  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_get_a_conference = self.api.get_a_conference(conference_id='fake_conference_id')

            mock_method.assert_called_once()

    def test_get_a_member(self):
        """Test case for get_a_member

        Get a Member  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_get_a_member = self.api.get_a_member(queue_id='fake_queue_id', call_id='fake_call_id')

            mock_method.assert_called_once()

    def test_get_a_participant(self):
        """Test case for get_a_participant

        Get a Participant  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_get_a_participant = self.api.get_a_participant(conference_id='fake_conference_id', call_id='fake_call_id')

            mock_method.assert_called_once()

    def test_get_a_queue(self):
        """Test case for get_a_queue

        Get a Queue  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_get_a_queue = self.api.get_a_queue(queue_id='fake_queue_id')

            mock_method.assert_called_once()

    def test_get_a_recording(self):
        """Test case for get_a_recording

        Get a Recording  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_get_a_recording = self.api.get_a_recording(recording_id='fake_recording_id')

            mock_method.assert_called_once()

    def test_get_an_account(self):
        """Test case for get_an_account

        Get an Account  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_get_an_account = self.api.get_an_account()

            mock_method.assert_called_once()

    def test_get_an_application(self):
        """Test case for get_an_application

        Get an Application  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_get_an_application = self.api.get_an_application(application_id='fake_application_id')

            mock_method.assert_called_once()

    def test_get_an_incoming_number(self):
        """Test case for get_an_incoming_number

        Get an Incoming Number  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_get_an_incoming_number = self.api.get_an_incoming_number(phone_number_id='fake_phone_number_id')

            mock_method.assert_called_once()

    def test_get_an_sms_message(self):
        """Test case for get_an_sms_message

        Get an SMS Message  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_get_an_sms_message = self.api.get_an_sms_message(message_id='fake_message_id')

            mock_method.assert_called_once()

    def test_get_head_member(self):
        """Test case for get_head_member

        Get Head Member  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_get_head_member = self.api.get_head_member(queue_id='fake_queue_id')

            mock_method.assert_called_once()

    def test_list_active_queues(self):
        """Test case for list_active_queues

        List Active Queues  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_list_active_queues = self.api.list_active_queues()

            mock_method.assert_called_once()

    def test_list_all_account_logs(self):
        """Test case for list_all_account_logs

        List All Account Logs  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_list_all_account_logs = self.api.list_all_account_logs()

            mock_method.assert_called_once()

    def test_list_an_application(self):
        """Test case for list_an_application

        List applications  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_list_an_application = self.api.list_an_application()

            mock_method.assert_called_once()

    def test_list_available_numbers(self):
        """Test case for list_available_numbers

        List available numbers  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_list_available_numbers = self.api.list_available_numbers()

            mock_method.assert_called_once()

    def test_list_call_logs(self):
        """Test case for list_call_logs

        List Call Logs  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_list_call_logs = self.api.list_call_logs(call_id='fake_call_id')

            mock_method.assert_called_once()

    def test_list_call_recordings(self):
        """Test case for list_call_recordings

        List Call Recordings  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_list_call_recordings = self.api.list_call_recordings(call_id='fake_call_id')

            mock_method.assert_called_once()

    def test_list_calls(self):
        """Test case for list_calls

        List Calls  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_list_calls = self.api.list_calls()

            mock_method.assert_called_once()

    def test_list_conferences(self):
        """Test case for list_conferences

        List Conferences  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_list_conferences = self.api.list_conferences()

            mock_method.assert_called_once()

    def test_list_incoming_numbers(self):
        """Test case for list_incoming_numbers

        List Incoming Numbers  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_list_incoming_numbers = self.api.list_incoming_numbers()

            mock_method.assert_called_once()

    def test_list_members(self):
        """Test case for list_members

        List Members  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_list_members = self.api.list_members(queue_id='fake_queue_id')

            mock_method.assert_called_once()

    def test_list_participants(self):
        """Test case for list_participants

        List Participants  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_list_participants = self.api.list_participants(conference_id='fake_conference_id')

            mock_method.assert_called_once()

    def test_list_recordings(self):
        """Test case for list_recordings

        List Recordings  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_list_recordings = self.api.list_recordings()

            mock_method.assert_called_once()

    def test_list_sms_messages(self):
        """Test case for list_sms_messages

        List SMS Messages  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_list_sms_messages = self.api.list_sms_messages()

            mock_method.assert_called_once()

    def test_make_a_call(self):
        """Test case for make_a_call

        Make a Call  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_make_a_call = self.api.make_a_call()

            mock_method.assert_called_once()

    def test_remove_a_participant(self):
        """Test case for remove_a_participant

        Remove a Participant  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_remove_a_participant = self.api.remove_a_participant(conference_id='fake_conference_id', call_id='fake_call_id')

            mock_method.assert_called_once()

    def test_send_an_sms_message(self):
        """Test case for send_an_sms_message

        Send an SMS Message  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            message_request = freeclimb.MessageRequest(_from='fake_sender_phone_number', to='fake_recipient_phone_number',text='Test message')
            self.test_send_an_sms_message = self.api.send_an_sms_message(message_request=message_request)

            mock_method.assert_called_once()

    def test_stream_a_recording_file(self):
        """Test case for stream_a_recording_file

        Stream a Recording File  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_stream_a_recording_file = self.api.stream_a_recording_file(recording_id='fake_recording_id')

            mock_method.assert_called_once()

    def test_update_a_conference(self):
        """Test case for update_a_conference

        Update a Conference  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_update_a_conference = self.api.update_a_conference(conference_id='fake_conference_id', update_conference_request=freeclimb.UpdateConferenceRequest())

            mock_method.assert_called_once()

    def test_update_a_live_call(self):
        """Test case for update_a_live_call

        Update a Live Call  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_update_a_live_call = self.api.update_a_live_call(call_id='fake_call_id', update_call_request=freeclimb.UpdateCallRequest(status='completed'))

            mock_method.assert_called_once()

    def test_update_a_participant(self):
        """Test case for update_a_participant

        Update a Participant  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_update_a_participant = self.api.update_a_participant(call_id='fake_call_id', conference_id='fake_conference_id', update_conference_participant_request=freeclimb.UpdateConferenceParticipantRequest())

            mock_method.assert_called_once()

    def test_update_a_queue(self):
        """Test case for update_a_queue

        Update a Queue  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_update_a_queue = self.api.update_a_queue(queue_id='fake_queue_id', queue_request=freeclimb.QueueRequest())

            mock_method.assert_called_once()

    def test_update_an_account(self):
        """Test case for update_an_account

        Manage an account  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_update_an_account = self.api.update_an_account(account_request=freeclimb.AccountRequest())

            mock_method.assert_called_once()

    def test_update_an_application(self):
        """Test case for update_an_application

        Update an application  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_update_an_application = self.api.update_an_application(application_id='fake_application_id',application_request=freeclimb.ApplicationRequest())

            mock_method.assert_called_once()

    def test_update_an_incoming_number(self):
        """Test case for update_an_incoming_number

        Update an Incoming Number  # noqa: E501
        """
        with mock.patch.object(freeclimb.ApiClient, 'call_api', return_value=None) as mock_method:
            self.test_update_an_incoming_number = self.api.update_an_incoming_number(phone_number_id='fake_phone_number_id',incoming_number_request=freeclimb.IncomingNumberRequest())

            mock_method.assert_called_once()


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from freeclimb.configuration import Configuration


class QueueMember(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'uri': 'str',
        'call_id': 'str',
        'wait_time': 'int',
        'position': 'int',
        'date_enqueued': 'str'
    }

    attribute_map = {
        'uri': 'uri',
        'call_id': 'callId',
        'wait_time': 'waitTime',
        'position': 'position',
        'date_enqueued': 'dateEnqueued'
    }

    def __init__(self, uri=None, call_id=None, wait_time=None, position=None, date_enqueued=None, local_vars_configuration=None):  # noqa: E501
        """QueueMember - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._uri = None
        self._call_id = None
        self._wait_time = None
        self._position = None
        self._date_enqueued = None
        self.discriminator = None

        if uri is not None:
            self.uri = uri
        if call_id is not None:
            self.call_id = call_id
        if wait_time is not None:
            self.wait_time = wait_time
        if position is not None:
            self.position = position
        if date_enqueued is not None:
            self.date_enqueued = date_enqueued

    @property
    def uri(self):
        """Gets the uri of this QueueMember.  # noqa: E501

        URI for this Queue Member resource, relative to the API base URL.  # noqa: E501

        :return: The uri of this QueueMember.  # noqa: E501
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """Sets the uri of this QueueMember.

        URI for this Queue Member resource, relative to the API base URL.  # noqa: E501

        :param uri: The uri of this QueueMember.  # noqa: E501
        :type: str
        """

        self._uri = uri

    @property
    def call_id(self):
        """Gets the call_id of this QueueMember.  # noqa: E501

        ID of the Call associated with this Queue Member.  # noqa: E501

        :return: The call_id of this QueueMember.  # noqa: E501
        :rtype: str
        """
        return self._call_id

    @call_id.setter
    def call_id(self, call_id):
        """Sets the call_id of this QueueMember.

        ID of the Call associated with this Queue Member.  # noqa: E501

        :param call_id: The call_id of this QueueMember.  # noqa: E501
        :type: str
        """

        self._call_id = call_id

    @property
    def wait_time(self):
        """Gets the wait_time of this QueueMember.  # noqa: E501

        Number of seconds the Member has been in the queue.  # noqa: E501

        :return: The wait_time of this QueueMember.  # noqa: E501
        :rtype: int
        """
        return self._wait_time

    @wait_time.setter
    def wait_time(self, wait_time):
        """Sets the wait_time of this QueueMember.

        Number of seconds the Member has been in the queue.  # noqa: E501

        :param wait_time: The wait_time of this QueueMember.  # noqa: E501
        :type: int
        """

        self._wait_time = wait_time

    @property
    def position(self):
        """Gets the position of this QueueMember.  # noqa: E501

        Member's current position in the Queue, 1 indexed.  # noqa: E501

        :return: The position of this QueueMember.  # noqa: E501
        :rtype: int
        """
        return self._position

    @position.setter
    def position(self, position):
        """Sets the position of this QueueMember.

        Member's current position in the Queue, 1 indexed.  # noqa: E501

        :param position: The position of this QueueMember.  # noqa: E501
        :type: int
        """

        self._position = position

    @property
    def date_enqueued(self):
        """Gets the date_enqueued of this QueueMember.  # noqa: E501

        Date that the Member was enqueued (GMT), given in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).  # noqa: E501

        :return: The date_enqueued of this QueueMember.  # noqa: E501
        :rtype: str
        """
        return self._date_enqueued

    @date_enqueued.setter
    def date_enqueued(self, date_enqueued):
        """Sets the date_enqueued of this QueueMember.

        Date that the Member was enqueued (GMT), given in RFC 1123 format (e.g., Mon, 15 Jun 2009 20:45:30 GMT).  # noqa: E501

        :param date_enqueued: The date_enqueued of this QueueMember.  # noqa: E501
        :type: str
        """

        self._date_enqueued = date_enqueued

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.to_camel_case(attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif value is None:
                continue
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QueueMember):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, QueueMember):
            return True

        return self.to_dict() != other.to_dict()

    def to_camel_case(self, snake_str):
        components = snake_str.split('_')
        return components[0] + ''.join(x.title() for x in components[1:])



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from freeclimb.configuration import Configuration


class OutDial(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'action_url': 'str',
        'call_connect_url': 'str',
        'calling_number': 'float',
        'destination': 'float',
        'if_machine': 'str',
        'if_machine_url': 'str',
        'send_digits': 'str',
        'status_callback_url': 'str',
        'timeout': 'int',
        'privacy_mode': 'bool'
    }

    attribute_map = {
        'action_url': 'actionUrl',
        'call_connect_url': 'callConnectUrl',
        'calling_number': 'callingNumber',
        'destination': 'destination',
        'if_machine': 'ifMachine',
        'if_machine_url': 'ifMachineUrl',
        'send_digits': 'sendDigits',
        'status_callback_url': 'statusCallbackUrl',
        'timeout': 'timeout',
        'privacy_mode': 'privacyMode'
    }

    def __init__(self, action_url=None, call_connect_url=None, calling_number=None, destination=None, if_machine=None, if_machine_url=None, send_digits=None, status_callback_url=None, timeout=None, privacy_mode=None, local_vars_configuration=None):  # noqa: E501
        """OutDial - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._action_url = None
        self._call_connect_url = None
        self._calling_number = None
        self._destination = None
        self._if_machine = None
        self._if_machine_url = None
        self._send_digits = None
        self._status_callback_url = None
        self._timeout = None
        self._privacy_mode = None
        self.discriminator = None

        self.action_url = action_url
        self.call_connect_url = call_connect_url
        self.calling_number = calling_number
        self.destination = destination
        if if_machine is not None:
            self.if_machine = if_machine
        if if_machine_url is not None:
            self.if_machine_url = if_machine_url
        if send_digits is not None:
            self.send_digits = send_digits
        if status_callback_url is not None:
            self.status_callback_url = status_callback_url
        if timeout is not None:
            self.timeout = timeout
        if privacy_mode is not None:
            self.privacy_mode = privacy_mode

    @property
    def action_url(self):
        """Gets the action_url of this OutDial.  # noqa: E501

        URL to which FreeClimb sends an HTTP POST request.   # noqa: E501

        :return: The action_url of this OutDial.  # noqa: E501
        :rtype: str
        """
        return self._action_url

    @action_url.setter
    def action_url(self, action_url):
        """Sets the action_url of this OutDial.

        URL to which FreeClimb sends an HTTP POST request.   # noqa: E501

        :param action_url: The action_url of this OutDial.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and action_url is None:  # noqa: E501
            raise ValueError("Invalid value for `action_url`, must not be `None`")  # noqa: E501

        self._action_url = action_url

    @property
    def call_connect_url(self):
        """Gets the call_connect_url of this OutDial.  # noqa: E501

        URL to which FreeClimb makes an HTTP POST request informing the result of the OutDial.  # noqa: E501

        :return: The call_connect_url of this OutDial.  # noqa: E501
        :rtype: str
        """
        return self._call_connect_url

    @call_connect_url.setter
    def call_connect_url(self, call_connect_url):
        """Sets the call_connect_url of this OutDial.

        URL to which FreeClimb makes an HTTP POST request informing the result of the OutDial.  # noqa: E501

        :param call_connect_url: The call_connect_url of this OutDial.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and call_connect_url is None:  # noqa: E501
            raise ValueError("Invalid value for `call_connect_url`, must not be `None`")  # noqa: E501

        self._call_connect_url = call_connect_url

    @property
    def calling_number(self):
        """Gets the calling_number of this OutDial.  # noqa: E501

        he caller ID to show to the called party when FreeClimb calls. This can be one of the following: The To or From number provided in the first Webhook to your webserver. Any phone number you have purchased from FreeClimb.  # noqa: E501

        :return: The calling_number of this OutDial.  # noqa: E501
        :rtype: float
        """
        return self._calling_number

    @calling_number.setter
    def calling_number(self, calling_number):
        """Sets the calling_number of this OutDial.

        he caller ID to show to the called party when FreeClimb calls. This can be one of the following: The To or From number provided in the first Webhook to your webserver. Any phone number you have purchased from FreeClimb.  # noqa: E501

        :param calling_number: The calling_number of this OutDial.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and calling_number is None:  # noqa: E501
            raise ValueError("Invalid value for `calling_number`, must not be `None`")  # noqa: E501

        self._calling_number = calling_number

    @property
    def destination(self):
        """Gets the destination of this OutDial.  # noqa: E501

        E.164 representation of the phone number to Call.   # noqa: E501

        :return: The destination of this OutDial.  # noqa: E501
        :rtype: float
        """
        return self._destination

    @destination.setter
    def destination(self, destination):
        """Sets the destination of this OutDial.

        E.164 representation of the phone number to Call.   # noqa: E501

        :param destination: The destination of this OutDial.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and destination is None:  # noqa: E501
            raise ValueError("Invalid value for `destination`, must not be `None`")  # noqa: E501

        self._destination = destination

    @property
    def if_machine(self):
        """Gets the if_machine of this OutDial.  # noqa: E501

        Specifies how FreeClimb should handle this OutDial if an answering machine answers the Call. Valid values: `redirect` invokes the ifMachineUrl for instructions. `hangup` hangs up the Call. The ifMachineUrl will not be invoked.  # noqa: E501

        :return: The if_machine of this OutDial.  # noqa: E501
        :rtype: str
        """
        return self._if_machine

    @if_machine.setter
    def if_machine(self, if_machine):
        """Sets the if_machine of this OutDial.

        Specifies how FreeClimb should handle this OutDial if an answering machine answers the Call. Valid values: `redirect` invokes the ifMachineUrl for instructions. `hangup` hangs up the Call. The ifMachineUrl will not be invoked.  # noqa: E501

        :param if_machine: The if_machine of this OutDial.  # noqa: E501
        :type: str
        """

        self._if_machine = if_machine

    @property
    def if_machine_url(self):
        """Gets the if_machine_url of this OutDial.  # noqa: E501

        When the `ifMachine` flag is set to `redirect`, this attribute specifies a URL to which FreeClimb makes a POST request when an answering machine or a fax machine is detected. This URL is required if the `ifMachine` flag is set to `redirect`. Otherwise, it should not be included.  # noqa: E501

        :return: The if_machine_url of this OutDial.  # noqa: E501
        :rtype: str
        """
        return self._if_machine_url

    @if_machine_url.setter
    def if_machine_url(self, if_machine_url):
        """Sets the if_machine_url of this OutDial.

        When the `ifMachine` flag is set to `redirect`, this attribute specifies a URL to which FreeClimb makes a POST request when an answering machine or a fax machine is detected. This URL is required if the `ifMachine` flag is set to `redirect`. Otherwise, it should not be included.  # noqa: E501

        :param if_machine_url: The if_machine_url of this OutDial.  # noqa: E501
        :type: str
        """

        self._if_machine_url = if_machine_url

    @property
    def send_digits(self):
        """Gets the send_digits of this OutDial.  # noqa: E501

        DTMF tones to play to the outdialed Call. This is typically used to dial a number and then dial an extension.  # noqa: E501

        :return: The send_digits of this OutDial.  # noqa: E501
        :rtype: str
        """
        return self._send_digits

    @send_digits.setter
    def send_digits(self, send_digits):
        """Sets the send_digits of this OutDial.

        DTMF tones to play to the outdialed Call. This is typically used to dial a number and then dial an extension.  # noqa: E501

        :param send_digits: The send_digits of this OutDial.  # noqa: E501
        :type: str
        """

        self._send_digits = send_digits

    @property
    def status_callback_url(self):
        """Gets the status_callback_url of this OutDial.  # noqa: E501

        When the outdialed Call leg terminates, FreeClimb sends a `callStatus` Webhook to the `statusCallbackUrl`. This is a notification only; any PerCL command returned is ignored.  # noqa: E501

        :return: The status_callback_url of this OutDial.  # noqa: E501
        :rtype: str
        """
        return self._status_callback_url

    @status_callback_url.setter
    def status_callback_url(self, status_callback_url):
        """Sets the status_callback_url of this OutDial.

        When the outdialed Call leg terminates, FreeClimb sends a `callStatus` Webhook to the `statusCallbackUrl`. This is a notification only; any PerCL command returned is ignored.  # noqa: E501

        :param status_callback_url: The status_callback_url of this OutDial.  # noqa: E501
        :type: str
        """

        self._status_callback_url = status_callback_url

    @property
    def timeout(self):
        """Gets the timeout of this OutDial.  # noqa: E501

        Maximum time in seconds the `OutDial` command waits for the called party to answer the Call. When a timeout occurs, FreeClimb invokes the `callConnectUrl` Webhook to report that the out-dialed Call has ended with a status of `noAnswer`.  # noqa: E501

        :return: The timeout of this OutDial.  # noqa: E501
        :rtype: int
        """
        return self._timeout

    @timeout.setter
    def timeout(self, timeout):
        """Sets the timeout of this OutDial.

        Maximum time in seconds the `OutDial` command waits for the called party to answer the Call. When a timeout occurs, FreeClimb invokes the `callConnectUrl` Webhook to report that the out-dialed Call has ended with a status of `noAnswer`.  # noqa: E501

        :param timeout: The timeout of this OutDial.  # noqa: E501
        :type: int
        """

        self._timeout = timeout

    @property
    def privacy_mode(self):
        """Gets the privacy_mode of this OutDial.  # noqa: E501

        Parameter `privacyMode` will not log the `text` as required by PCI compliance.  # noqa: E501

        :return: The privacy_mode of this OutDial.  # noqa: E501
        :rtype: bool
        """
        return self._privacy_mode

    @privacy_mode.setter
    def privacy_mode(self, privacy_mode):
        """Sets the privacy_mode of this OutDial.

        Parameter `privacyMode` will not log the `text` as required by PCI compliance.  # noqa: E501

        :param privacy_mode: The privacy_mode of this OutDial.  # noqa: E501
        :type: bool
        """

        self._privacy_mode = privacy_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.to_camel_case(attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif value is None:
                continue
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OutDial):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OutDial):
            return True

        return self.to_dict() != other.to_dict()

    def to_camel_case(self, snake_str):
        components = snake_str.split('_')
        return components[0] + ''.join(x.title() for x in components[1:])



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from freeclimb.configuration import Configuration


class AccountResultAllOf(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'str',
        'api_key': 'str',
        'alias': 'str',
        'label': 'str',
        'type': 'str',
        'status': 'str',
        'subresource_uris': 'object'
    }

    attribute_map = {
        'account_id': 'accountId',
        'api_key': 'apiKey',
        'alias': 'alias',
        'label': 'label',
        'type': 'type',
        'status': 'status',
        'subresource_uris': 'subresourceUris'
    }

    def __init__(self, account_id=None, api_key=None, alias=None, label=None, type=None, status=None, subresource_uris=None, local_vars_configuration=None):  # noqa: E501
        """AccountResultAllOf - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._api_key = None
        self._alias = None
        self._label = None
        self._type = None
        self._status = None
        self._subresource_uris = None
        self.discriminator = None

        if account_id is not None:
            self.account_id = account_id
        if api_key is not None:
            self.api_key = api_key
        if alias is not None:
            self.alias = alias
        if label is not None:
            self.label = label
        if type is not None:
            self.type = type
        if status is not None:
            self.status = status
        if subresource_uris is not None:
            self.subresource_uris = subresource_uris

    @property
    def account_id(self):
        """Gets the account_id of this AccountResultAllOf.  # noqa: E501

        String that uniquely identifies this account resource.  # noqa: E501

        :return: The account_id of this AccountResultAllOf.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this AccountResultAllOf.

        String that uniquely identifies this account resource.  # noqa: E501

        :param account_id: The account_id of this AccountResultAllOf.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def api_key(self):
        """Gets the api_key of this AccountResultAllOf.  # noqa: E501

        The API key assigned to this account. This token must be kept a secret by the customer.  # noqa: E501

        :return: The api_key of this AccountResultAllOf.  # noqa: E501
        :rtype: str
        """
        return self._api_key

    @api_key.setter
    def api_key(self, api_key):
        """Sets the api_key of this AccountResultAllOf.

        The API key assigned to this account. This token must be kept a secret by the customer.  # noqa: E501

        :param api_key: The api_key of this AccountResultAllOf.  # noqa: E501
        :type: str
        """

        self._api_key = api_key

    @property
    def alias(self):
        """Gets the alias of this AccountResultAllOf.  # noqa: E501

        A description for this account.  # noqa: E501

        :return: The alias of this AccountResultAllOf.  # noqa: E501
        :rtype: str
        """
        return self._alias

    @alias.setter
    def alias(self, alias):
        """Sets the alias of this AccountResultAllOf.

        A description for this account.  # noqa: E501

        :param alias: The alias of this AccountResultAllOf.  # noqa: E501
        :type: str
        """

        self._alias = alias

    @property
    def label(self):
        """Gets the label of this AccountResultAllOf.  # noqa: E501

        A string that identifies a category or group to which the account belongs.  # noqa: E501

        :return: The label of this AccountResultAllOf.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this AccountResultAllOf.

        A string that identifies a category or group to which the account belongs.  # noqa: E501

        :param label: The label of this AccountResultAllOf.  # noqa: E501
        :type: str
        """

        self._label = label

    @property
    def type(self):
        """Gets the type of this AccountResultAllOf.  # noqa: E501

        The type of this account. It is one of: trial or full.  # noqa: E501

        :return: The type of this AccountResultAllOf.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this AccountResultAllOf.

        The type of this account. It is one of: trial or full.  # noqa: E501

        :param type: The type of this AccountResultAllOf.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def status(self):
        """Gets the status of this AccountResultAllOf.  # noqa: E501

        The status of this account. It is one of: active, suspended, or closed.  # noqa: E501

        :return: The status of this AccountResultAllOf.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this AccountResultAllOf.

        The status of this account. It is one of: active, suspended, or closed.  # noqa: E501

        :param status: The status of this AccountResultAllOf.  # noqa: E501
        :type: str
        """
        allowed_values = ["active", "suspended", "closed"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def subresource_uris(self):
        """Gets the subresource_uris of this AccountResultAllOf.  # noqa: E501

        The list of subresources for this account.  # noqa: E501

        :return: The subresource_uris of this AccountResultAllOf.  # noqa: E501
        :rtype: object
        """
        return self._subresource_uris

    @subresource_uris.setter
    def subresource_uris(self, subresource_uris):
        """Sets the subresource_uris of this AccountResultAllOf.

        The list of subresources for this account.  # noqa: E501

        :param subresource_uris: The subresource_uris of this AccountResultAllOf.  # noqa: E501
        :type: object
        """

        self._subresource_uris = subresource_uris

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.to_camel_case(attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif value is None:
                continue
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccountResultAllOf):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AccountResultAllOf):
            return True

        return self.to_dict() != other.to_dict()

    def to_camel_case(self, snake_str):
        components = snake_str.split('_')
        return components[0] + ''.join(x.title() for x in components[1:])



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from freeclimb.configuration import Configuration


class QueueResultAllOf(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'str',
        'queue_id': 'str',
        'alias': 'str',
        'max_size': 'int',
        'current_size': 'str',
        'average_wait_time': 'str',
        'subresource_uris': 'object'
    }

    attribute_map = {
        'account_id': 'accountId',
        'queue_id': 'queueId',
        'alias': 'alias',
        'max_size': 'maxSize',
        'current_size': 'currentSize',
        'average_wait_time': 'averageWaitTime',
        'subresource_uris': 'subresourceUris'
    }

    def __init__(self, account_id=None, queue_id=None, alias=None, max_size=None, current_size=None, average_wait_time=None, subresource_uris=None, local_vars_configuration=None):  # noqa: E501
        """QueueResultAllOf - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._queue_id = None
        self._alias = None
        self._max_size = None
        self._current_size = None
        self._average_wait_time = None
        self._subresource_uris = None
        self.discriminator = None

        if account_id is not None:
            self.account_id = account_id
        if queue_id is not None:
            self.queue_id = queue_id
        if alias is not None:
            self.alias = alias
        if max_size is not None:
            self.max_size = max_size
        if current_size is not None:
            self.current_size = current_size
        if average_wait_time is not None:
            self.average_wait_time = average_wait_time
        if subresource_uris is not None:
            self.subresource_uris = subresource_uris

    @property
    def account_id(self):
        """Gets the account_id of this QueueResultAllOf.  # noqa: E501

        ID of the account that created this Queue.  # noqa: E501

        :return: The account_id of this QueueResultAllOf.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this QueueResultAllOf.

        ID of the account that created this Queue.  # noqa: E501

        :param account_id: The account_id of this QueueResultAllOf.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def queue_id(self):
        """Gets the queue_id of this QueueResultAllOf.  # noqa: E501

        A string that uniquely identifies this Queue resource.  # noqa: E501

        :return: The queue_id of this QueueResultAllOf.  # noqa: E501
        :rtype: str
        """
        return self._queue_id

    @queue_id.setter
    def queue_id(self, queue_id):
        """Sets the queue_id of this QueueResultAllOf.

        A string that uniquely identifies this Queue resource.  # noqa: E501

        :param queue_id: The queue_id of this QueueResultAllOf.  # noqa: E501
        :type: str
        """

        self._queue_id = queue_id

    @property
    def alias(self):
        """Gets the alias of this QueueResultAllOf.  # noqa: E501

        A description for this Queue.  # noqa: E501

        :return: The alias of this QueueResultAllOf.  # noqa: E501
        :rtype: str
        """
        return self._alias

    @alias.setter
    def alias(self, alias):
        """Sets the alias of this QueueResultAllOf.

        A description for this Queue.  # noqa: E501

        :param alias: The alias of this QueueResultAllOf.  # noqa: E501
        :type: str
        """

        self._alias = alias

    @property
    def max_size(self):
        """Gets the max_size of this QueueResultAllOf.  # noqa: E501

        The maximum number of Calls permitted in the Queue. Default is 100. Maximum is 1000.  # noqa: E501

        :return: The max_size of this QueueResultAllOf.  # noqa: E501
        :rtype: int
        """
        return self._max_size

    @max_size.setter
    def max_size(self, max_size):
        """Sets the max_size of this QueueResultAllOf.

        The maximum number of Calls permitted in the Queue. Default is 100. Maximum is 1000.  # noqa: E501

        :param max_size: The max_size of this QueueResultAllOf.  # noqa: E501
        :type: int
        """

        self._max_size = max_size

    @property
    def current_size(self):
        """Gets the current_size of this QueueResultAllOf.  # noqa: E501

        Count of Calls currently in the Queue.  # noqa: E501

        :return: The current_size of this QueueResultAllOf.  # noqa: E501
        :rtype: str
        """
        return self._current_size

    @current_size.setter
    def current_size(self, current_size):
        """Sets the current_size of this QueueResultAllOf.

        Count of Calls currently in the Queue.  # noqa: E501

        :param current_size: The current_size of this QueueResultAllOf.  # noqa: E501
        :type: str
        """

        self._current_size = current_size

    @property
    def average_wait_time(self):
        """Gets the average_wait_time of this QueueResultAllOf.  # noqa: E501

        Average wait time (in seconds) of all Calls in the Queue.  # noqa: E501

        :return: The average_wait_time of this QueueResultAllOf.  # noqa: E501
        :rtype: str
        """
        return self._average_wait_time

    @average_wait_time.setter
    def average_wait_time(self, average_wait_time):
        """Sets the average_wait_time of this QueueResultAllOf.

        Average wait time (in seconds) of all Calls in the Queue.  # noqa: E501

        :param average_wait_time: The average_wait_time of this QueueResultAllOf.  # noqa: E501
        :type: str
        """

        self._average_wait_time = average_wait_time

    @property
    def subresource_uris(self):
        """Gets the subresource_uris of this QueueResultAllOf.  # noqa: E501

        List of subresources for this Queue (which includes Queue members).  # noqa: E501

        :return: The subresource_uris of this QueueResultAllOf.  # noqa: E501
        :rtype: object
        """
        return self._subresource_uris

    @subresource_uris.setter
    def subresource_uris(self, subresource_uris):
        """Sets the subresource_uris of this QueueResultAllOf.

        List of subresources for this Queue (which includes Queue members).  # noqa: E501

        :param subresource_uris: The subresource_uris of this QueueResultAllOf.  # noqa: E501
        :type: object
        """

        self._subresource_uris = subresource_uris

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.to_camel_case(attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif value is None:
                continue
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QueueResultAllOf):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, QueueResultAllOf):
            return True

        return self.to_dict() != other.to_dict()

    def to_camel_case(self, snake_str):
        components = snake_str.split('_')
        return components[0] + ''.join(x.title() for x in components[1:])



# coding: utf-8

"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from freeclimb.configuration import Configuration


class AccountRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'alias': 'str',
        'label': 'str'
    }

    attribute_map = {
        'alias': 'alias',
        'label': 'label'
    }

    def __init__(self, alias=None, label=None, local_vars_configuration=None):  # noqa: E501
        """AccountRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._alias = None
        self._label = None
        self.discriminator = None

        if alias is not None:
            self.alias = alias
        if label is not None:
            self.label = label

    @property
    def alias(self):
        """Gets the alias of this AccountRequest.  # noqa: E501

        Description for this account.  # noqa: E501

        :return: The alias of this AccountRequest.  # noqa: E501
        :rtype: str
        """
        return self._alias

    @alias.setter
    def alias(self, alias):
        """Sets the alias of this AccountRequest.

        Description for this account.  # noqa: E501

        :param alias: The alias of this AccountRequest.  # noqa: E501
        :type: str
        """

        self._alias = alias

    @property
    def label(self):
        """Gets the label of this AccountRequest.  # noqa: E501

        Group to which this account belongs.  # noqa: E501

        :return: The label of this AccountRequest.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this AccountRequest.

        Group to which this account belongs.  # noqa: E501

        :param label: The label of this AccountRequest.  # noqa: E501
        :type: str
        """

        self._label = label

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.to_camel_case(attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif value is None:
                continue
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccountRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AccountRequest):
            return True

        return self.to_dict() != other.to_dict()

    def to_camel_case(self, snake_str):
        components = snake_str.split('_')
        return components[0] + ''.join(x.title() for x in components[1:])
